# NbHub 📡
[![Build Status](https://travis-ci.org/duarteocarmo/nbhub.svg?branch=master)](https://travis-ci.org/duarteocarmo/think-cell) [![Coverage Status](https://coveralls.io/repos/github/duarteocarmo/nbhub/badge.svg?branch=master&service=github)](https://coveralls.io/github/duarteocarmo/think-cell?branch=master) [![PyPI version shields.io](https://img.shields.io/pypi/v/nbhub.svg)](https://pypi.python.org/pypi/thinkcell/) [![Supported Python versions](https://img.shields.io/pypi/pyversions/nbhub.svg)](https://pypi.org/project/thinkcell/) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black) [![PyPI downloads](https://img.shields.io/pypi/dm/nbhub.svg)](https://pypistats.org/packages/thinkcell) [![GitHub license](https://img.shields.io/github/license/duarteocarmo/nbhub.svg)](https://github.com/duarteocarmo/think-cell/blob/master/LICENSE) [![made with: Vim](https://img.shields.io/badge/made%20with-Vim-019331)](https://github.com/vim/vim)

Publish jupyter notebooks from the command line.